@@ -25,8 +25,9 @@ class HttpClient(object):
     SDK_URL = 'https://sdk.split.io/api'
     EVENTS_URL = 'https://events.split.io/api'
     AUTH_URL = 'https://auth.split.io/api'
+    TELEMETRY_URL = 'https://telemetry.split.io/api'
 
-    def __init__(self, timeout=None, sdk_url=None, events_url=None, auth_url=None):
+    def __init__(self, timeout=None, sdk_url=None, events_url=None, auth_url=None, telemetry_url=None):
         """
         Class constructor.
 
@@ -38,12 +39,15 @@ class HttpClient(object):
         :type events_url: str
         :param auth_url: Optional alternative auth URL.
         :type auth_url: str
+        :param telemetry_url: Optional alternative telemetry URL.
+        :type telemetry_url: str
         """
         self._timeout = timeout/1000 if timeout else None  # Convert ms to seconds.
         self._urls = {
             'sdk': sdk_url if sdk_url is not None else self.SDK_URL,
             'events': events_url if events_url is not None else self.EVENTS_URL,
             'auth': auth_url if auth_url is not None else self.AUTH_URL,
+            'telemetry': telemetry_url if telemetry_url is not None else self.TELEMETRY_URL,
         }
 
     def _build_url(self, server, path):
