@@ -127,12 +127,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
@@ -334,12 +328,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
@@ -514,12 +502,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
@@ -704,12 +686,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
@@ -931,12 +907,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
@@ -1168,12 +1138,6 @@ class StreamingIntegrationTests(object):
                                                          '[?occupancy=metrics.publishers]control_sec'])
         assert qs['v'][0] == '1.1'
 
-        # Initial apikey validation
-        req = split_backend_requests.get()
-        assert req.method == 'GET'
-        assert req.path == '/api/segmentChanges/__SOME_INVALID_SEGMENT__?since=-1'
-        assert req.headers['authorization'] == 'Bearer some_apikey'
-
         # Initial splits fetch
         req = split_backend_requests.get()
         assert req.method == 'GET'
